from sshed import servers
import argparse


class ServerAction(argparse.Action):

    def __call__(self, parser, namespace, values, option_string=None):
        setattr(namespace, self.dest, servers.from_conf(values))



class Command(object):

    """
        sshed server.run returns back a command object. This object should
        have the return code, stderr, stdout and a couple functions.

        Current this allows a script to retry a command.
    """

    def __init__(cmd, command_str, host):
        cmd.command_str = command_str
        cmd.host = host

    def retry(self):
        return self.host.run(self.command_str)



from setuptools import setup
from sshed import version
import os

readme_file = open(os.path.abspath(
    os.path.join(os.path.dirname(__file__),'README.markdown')))

setup(
    name='sshed',
    author='Colin Wood',
    author_email='cwood06@gmail.com',
    install_requires=[
        'ssh>=1.7.14',
    ],
    long_description=readme_file.read(),
    url='http://cwood.github.com/sshed/',
    version=version,
    packages=['sshed'],
    description='Minimal Parmaiko/ssh2 wrapper to make working with SSH easy.',
)
